==> cactoos_0.48.orig.tar.gz: cactoos-0.48/src/main/java/org/cactoos/iterable/IterableOfBytes.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos.iterable;

import java.nio.charset.StandardCharsets;
import java.util.Iterator;
import org.cactoos.Text;
import org.cactoos.iterator.IteratorOfBytes;

/**
 * Iterable of bytes.
 *
 * @since 1.0
 */
public final class IterableOfBytes extends IterableEnvelope<Byte> {

    /**
     * Ctor.
     * @param bytes Bytes
     */
    public IterableOfBytes(final byte... bytes) {
        this(new IteratorOfBytes(bytes));
    }

    /**
     * Ctor.
     * @param bytes Iterator
     */
    public IterableOfBytes(final Iterator<Byte> bytes) {
        super(new IterableOf<>(bytes));
    }

    /**
     * Ctor.
     * @param str String
     */
    public IterableOfBytes(final String str) {
        this(str.getBytes(StandardCharsets.UTF_8));
    }

    /**
     * Ctor.
     * @param txt Text
     */
    public IterableOfBytes(final Text txt) {
        this(txt.toString());
    }
}

==> cactoos_0.49.orig.tar.gz: cactoos-0.49/src/main/java/org/cactoos/iterable/IterableOfBytes.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos.iterable;

import org.cactoos.Bytes;
import org.cactoos.Text;
import org.cactoos.bytes.BytesOf;
import org.cactoos.iterator.IteratorOfBytes;

/**
 * Iterable of bytes.
 *
 * @since 1.0
 */
public final class IterableOfBytes extends IterableEnvelope<Byte> {

    /**
     * Ctor.
     * @param txt Text
     */
    public IterableOfBytes(final Text txt) {
        this(new BytesOf(txt));
    }

    /**
     * Ctor.
     * @param str String
     */
    public IterableOfBytes(final String str) {
        this(new BytesOf(str));
    }

    /**
     * Ctor.
     * @param bytes Bytes
     */
    public IterableOfBytes(final byte... bytes) {
        this(new BytesOf(bytes));
    }

    /**
     * Ctor.
     * @param bytes Bytes to iterate
     */
    public IterableOfBytes(final Bytes bytes) {
        super(new IterableOf<>(() -> new IteratorOfBytes(bytes)));
    }
}
